#
# spec file for package python-pyscard
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2011 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname pyscard
Name:           python-pyscard
Version:        2.2.1
Release:        1.1
Summary:        Python module adding smart card support
License:        LGPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://pyscard.sourceforge.io/
Source:         https://files.pythonhosted.org/packages/source/p/pyscard/pyscard-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  swig
Requires:       pcsc-ccid
%python_subpackages

%description
Python-pyscard consists of smartcard.scard, an extension module wrapping
Windows smart card base components (also known as PCSC) on Windows and PCSC
lite on linux and Mac OS X Tiger and Leopard, and smartcard, a higher level
python framework built on top of the raw PCSC API.

%prep
%setup -q -n %{modname}-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc ChangeLog README.md
%{python_sitearch}/pyscard*
%{python_sitearch}/smartcard

%changelog
* Tue Jan 14 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.1
  * waitforcardevent(): do not miss events between 2 calls.
  * Test, fix, and simplify ATR parsing.
* Sun Oct 20 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * PCSCCardRequest:
  - handle KeyboardInterrupt in waitforcard() & waitforcardevent()
  - use a local PC/SC context to avoid locks
  * smartcard.util.padd(): do NOT modify the input parameter
  * CardMonitoring: a timeout exception IS expected
  * Fix pydoctor documentation
  * wx: fix module and examples
  * Remove Python 2 conditional code
  * Test and improve the synchronization code
  * Test and update the `Observer.py` code
  * Remove `ClassLoader.py`
  * Migrate a `src/` layout
  * Migrate test/* from unittest to pytest
  * Add missing GSM 03.38 symbols for decoding
  * Support only Python 3.9 and higher
  * Remove the Python 2.x-only Pyro dependency
  * Migrate CI to use the official Coveralls action
  * Standardize local and CI testing to use tox
  * Build wheels in CI for all supported Python versions
  * Build the docs as a part of the test suite
  * Begin to add type annotations to the package
  * Deprecate the `HexListToBinString`, `BinStringToHexList`,
    `hl2bs`, and `bs2hl` utility functions
  * Support "64" as an ATR baud rate adjustment integer
    (ISO 7816-3 2006)
* Mon Sep  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.1
  * Fix a regression introduced in 2.1.0
- Update to version 2.1.0
  * PCSCCardRequest: fix active polling (was a 0.1 sec loop)
  * Fix use of undefined variable 'hresult' in exceptions
  * Fix print() use in pyscard user’s guide
  * Fix deprecation warnings
  * Minor changes
  * some more pylint-detected fixes.
* Mon Jun  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.10
  * CardMonitoringThread(): do not catch unexpected exceptions
* Sat Apr  6 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.9
  * fix a bug with CardRequestTimeoutException introduced in 2.0.8
  * Minor changes
* Sat Mar  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.8
  * Make CardMonitor() thread safe on Python 3.12
  * Add hresult value in exceptions
  * Improve documentation
  * Check swig is installed on build
  * Remove use of imp module for wx (GUI)
  * Makefile: modernize use of setup.py
- Drop not longer needed patch:
  * 0001-Remove-use-of-imp-module-for-wx-GUI.patch
* Wed Feb  7 2024 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-Remove-use-of-imp-module-for-wx-GUI.patch
    Fix build for python >= 3.12
* Fri Apr  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.7
  * do not include the generated HTML documentation in the archive
- Update to version 2.0.6
  * handle SCARD_E_NO_SERVICE on Windows (on last reader removal)
  * add support of MSYS2/mingw environment on Windows
  * improve documentation
  * minor changes
* Thu Sep 29 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.5
  * no functional changes
- Update to version 2.0.4
  * Fix a problem on PCSCCardConnection.disconnect
  * Add support of BaseSCardException(hresult) format
  * Do not use deprecated distutils anymore
- Update to version 2.0.3
  * PCSCExceptions: include error code in the message
* Tue Apr 19 2022 Marcus Meissner <meissner@suse.com>
- use https url
* Wed Nov  3 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Wed Sep 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.2
  * Restrict MAX_BUFFER_SIZE_EXTENDED to 65535 and fix an issue
    on Lenovo laptops with NXP NFC readers
  * SmartcardException: display a positive PCSC error code
* Thu Aug 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  * Add .reconnect() method to high-level API
  * Use Python3 by default
  * Handle bogus ACS ACR122U PICC reader
* Sat Jan  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * SCardStatus(): Fix a crash in case of PC/SC error
  * toASCIIString(): replace non-ASCII char by '.'
* Sun Nov 24 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.9.9
  * test: fix Exception test on 32-bits CPU
* Thu Apr  4 2019 Torsten Gruner <t.gruner@katodev.de>
- Fix Exception test on 32-bits CPU. Issue #72
* Mon Mar 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.9.8
  * SmartcardException: store the PC/SC return code in hresult
  * CardMonitoring: stop the looping only if PCSC exited
  * Minor documentation improvements
* Wed Jun 20 2018 mardnh@gmx.de
- Update to version 1.9.7
  * Modify CardMonitoring's deleteObserver method to cleanly remove threads
  * Python 3: fix smartcard/Synchronization.py
  * Python 3: Fix SCardGetErrorMessage() on Windows
  * PCSCPart10: add parseFeatureRequest(), parseTlvProperties()
  * Fix PEP8 warnings
  * Minor documentation improvements
* Mon Nov 27 2017 t.gruner@katodev.de
- update to version 1.9.6 (August 2017)
  - include test/__init__.py in the archive tarball.
    "make test" now works. That fixes build using Python 3.6
- fix spec file
* Fri May  5 2017 t.gruner@katodev.de
- single spec for python 2 and python 3
- Update to version 1.9.5 (Feb 2017)
  - SCardGetStatusChange(): fix a memory leak with Python 3
  - SCardTransmit(): use SCARD_PCI_RAW for undefined protocol
  - Improve epydoc documentation
- verison 1.9.4 (May 2016)
  - Fix installation using pip and easy_install
  - Avoid El Capitan SCardGetAttrib bug
  - CardConnection: Add context management
  - PCSCCardConnection: raise NoCardException if SCARD_E_NO_SMARTCARD
  - Stop CardMonitor monitor thread after traceback print.
  - minor improvements
- verison 1.9.3 (March 2016)
  - Fix SCardControl() on Windows 7
  - Fix installation using pip and easy_install
- verison 1.9.2 (February 2016)
  - Fix toBytes regression
  - Fix installation using pip
  - improve pydoc documentation
  - user-guide.rst: use real sample codes
  - minor improvements
- verison 1.9.1 (September 2015)
  - Create a new version so that the upload to Pypi does _not_
    contain the swig generated files.
* Fri Oct 16 2015 t.gruner@katodev.de
- Version 1.9.0 (August 2015)
  - add Python3 support (Python2 is still supported)
  - fix a lot of pylint warnings
  - smartcard/test/* replace deprecated assert calls
  - add tox support and coverage reports, run test suite on Travis
  - add Travis CI support to automatically build on Unix
  - add AppVeyor support to automatically build on Windows
  - minor bugs fixed
  - Big thank you to Alex Willmer for his work on pyscard
- Version 1.7.0 (June 2015)
  - PCSCCardConnection: Fix a problem with mode=SCARD_SHARE_DIRECT
  - add support of cygwin as a build platform
  - Fix a problem with Windows Remote Desktop
  - Switch from distutils to setuptools
  - dropped support for Python 2.5 and earlier (Alex Willmer)
  - dropped support for OS X 10.5 (Leopard) and earlier (Alex Willmer)
  - minor bugs fixed
* Thu Jul 16 2015 t.gruner@katodev.de
- move changelog to a file
* Sat Jan 11 2014 pedro@pgalves - 1.6.16
- added support for windows 64bit amd64 (Jean-Daniel Aussel)
- support python "new" classes (derive classes from object) (Ludovic Rousseau from chrysn feature request ID 3110077)
- fixed Reader.__eq__() (Ludovic Rousseau from Bernard Paulus bug ID 3418113)
- fixed extended APDU transmit buffer too short by 2 (Jean-Daniel Aussel from bugs ID 2914636 and 3106761)
- make Card and Reader objects hashable (Jean-Daniel Aussel from Hans-Peter Jansen feature request and patch)
- convert the user guide to python-Sphinx
* Fri May 27 2011 hpj@urpla.net - 1.6.14
- update to 1.6.14 svn 529
* Wed May 25 2011 hpj@urpla.net - 1.6.12
- add docs
* Wed May 25 2011 hpj@urpla.net - 1.6.12
- initial version
